@@ -1046,14 +1046,18 @@ void MainWindow::mainRaiseAndShine() {
   if (!isVisible()) setMeVisible(true);
   if (isMinimized()) showNormal();
   this->activateWindow();
-};
+  statusBar()->showMessage(
+    tr("Only one instance of %1 can be launched at same time.")
+    .arg(APP_SHORT_NAME)
+  );
+}
 
 void MainWindow::showNotifycation(const QString &header,
                                   const QString &message) {
 #ifdef WITH_DBUS
   QVariantList args;
   args << QString(APP_NAME);
-  args << QVariant(QVariant::UInt);
+  args << QVariant::fromValue(123u);
   args << QVariant("q4wine");
   args << QString("%1: %2").arg(APP_NAME).arg(header);
   args << message;
