@@ -49,7 +49,7 @@ PrefixConfigWidget::PrefixConfigWidget(QWidget *parent) : QWidget(parent) {
   cbPrefixes->setSizePolicy(QSizePolicy::MinimumExpanding,
                             QSizePolicy::Maximum);
   cbPrefixes->setMinimumWidth(180);
-  connect(cbPrefixes.get(), SIGNAL(currentIndexChanged(QString)), this,
+  connect(cbPrefixes.get(), SIGNAL(currentTextChanged(QString)), this,
           SIGNAL(prefixIndexChanged(QString)));
 
   treeToolBar->addWidget(cbPrefixes.get());
